=====================
Project Release Notes
=====================

For information on how to create release notes, please consult the
`Release Notes documentation <http://docs.openstack.org/developer/reno/>`_.
